@@ -605,7 +605,7 @@ class Resources(BkResources):
                 resource = resource.replace(cdn_base, CDN_DIST)
             if self.mode == 'server':
                 resource = resource.replace(CDN_DIST, LOCAL_DIST)
-            if (resource.startswith(state.base_url) or resource.startswith('static/')):
+            if resource.startswith((state.base_url, "static/")):
                 if resource.startswith(state.base_url):
                     resource = resource[len(state.base_url):]
                 if state.rel_path:
@@ -674,10 +674,11 @@ class Resources(BkResources):
         # Inline local dist resources
         css_files = self._collect_external_resources("__css__")
         self.extra_resources(css_files, '__css__')
-        raw += [
-            (DIST_DIR / css.replace(CDN_DIST, '')).read_text(encoding='utf-8')
-            for css in css_files if is_cdn_url(css)
-        ]
+        if self.mode.lower() != 'cdn':
+            raw += [
+                (DIST_DIR / css.replace(CDN_DIST, '')).read_text(encoding='utf-8')
+                for css in css_files if is_cdn_url(css)
+            ]
 
         # Add local CSS files
         for cssf in config.css_files:
