@@ -1,6 +1,6 @@
 import {ModelEvent} from "@bokehjs/core/bokeh_events"
 import * as p from "@bokehjs/core/properties"
-import {Attrs} from "@bokehjs/core/types"
+import type {Attrs} from "@bokehjs/core/types"
 import {Markup} from "@bokehjs/models/widgets/markup"
 import {PanelMarkupView} from "./layout";
 import {serializeEvent} from "./event-to-object";
