@@ -201,6 +201,13 @@ def test_cache_clear():
     fn.clear()
     assert fn(0, 0) == 1
 
+def test_cache_clear_before_cached():
+    # https://github.com/holoviz/panel/issues/5968
+    global OFFSET
+    OFFSET.clear()
+    fn = cache(function_with_args)
+    fn.clear()
+
 def test_per_session_cache(document):
     global OFFSET
     OFFSET.clear()
